==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/soap/wseventing/model/Subscribe.java <==

package org.somda.sdc.dpws.soap.wseventing.model;

import java.time.Duration;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.common.util.DurationAdapter;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="EndTo" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType" minOccurs="0"/&gt;
 *         &lt;element name="Delivery" type="{http://schemas.xmlsoap.org/ws/2004/08/eventing}DeliveryType"/&gt;
 *         &lt;element name="Expires" type="{http://www.w3.org/2001/XMLSchema}duration" minOccurs="0"/&gt;
 *         &lt;element name="Filter" type="{http://schemas.xmlsoap.org/ws/2004/08/eventing}FilterType" minOccurs="0"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "endTo",
    "delivery",
    "expires",
    "filter",
    "any"
})
@XmlRootElement(name = "Subscribe", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
public class Subscribe implements ToString2
{

    @XmlElement(name = "EndTo", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
    protected EndpointReferenceType endTo;
    @XmlElement(name = "Delivery", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing", required = true)
    protected DeliveryType delivery;
    @XmlElement(name = "Expires", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing", type = String.class)
    @XmlJavaTypeAdapter(DurationAdapter.class)
    @XmlSchemaType(name = "duration")
    protected Duration expires;
    @XmlElement(name = "Filter", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
    protected FilterType filter;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der endTo-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getEndTo() {
        return endTo;
    }

    /**
     * Legt den Wert der endTo-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setEndTo(EndpointReferenceType value) {
        this.endTo = value;
    }

    /**
     * Ruft den Wert der delivery-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link DeliveryType }
     *     
     */
    public DeliveryType getDelivery() {
        return delivery;
    }

    /**
     * Legt den Wert der delivery-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link DeliveryType }
     *     
     */
    public void setDelivery(DeliveryType value) {
        this.delivery = value;
    }

    /**
     * Ruft den Wert der expires-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Duration getExpires() {
        return expires;
    }

    /**
     * Legt den Wert der expires-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setExpires(Duration value) {
        this.expires = value;
    }

    /**
     * Ruft den Wert der filter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link FilterType }
     *     
     */
    public FilterType getFilter() {
        return filter;
    }

    /**
     * Legt den Wert der filter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link FilterType }
     *     
     */
    public void setFilter(FilterType value) {
        this.filter = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final Subscribe that = ((Subscribe) object);
        {
            EndpointReferenceType leftEndTo;
            leftEndTo = this.getEndTo();
            EndpointReferenceType rightEndTo;
            rightEndTo = that.getEndTo();
            if (this.endTo!= null) {
                if (that.endTo!= null) {
                    if (!leftEndTo.equals(rightEndTo)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.endTo!= null) {
                    return false;
                }
            }
        }
        {
            DeliveryType leftDelivery;
            leftDelivery = this.getDelivery();
            DeliveryType rightDelivery;
            rightDelivery = that.getDelivery();
            if (this.delivery!= null) {
                if (that.delivery!= null) {
                    if (!leftDelivery.equals(rightDelivery)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.delivery!= null) {
                    return false;
                }
            }
        }
        {
            Duration leftExpires;
            leftExpires = this.getExpires();
            Duration rightExpires;
            rightExpires = that.getExpires();
            if (this.expires!= null) {
                if (that.expires!= null) {
                    if (!leftExpires.equals(rightExpires)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.expires!= null) {
                    return false;
                }
            }
        }
        {
            FilterType leftFilter;
            leftFilter = this.getFilter();
            FilterType rightFilter;
            rightFilter = that.getFilter();
            if (this.filter!= null) {
                if (that.filter!= null) {
                    if (!leftFilter.equals(rightFilter)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.filter!= null) {
                    return false;
                }
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            EndpointReferenceType theEndTo;
            theEndTo = this.getEndTo();
            if (this.endTo!= null) {
                currentHashCode += theEndTo.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            DeliveryType theDelivery;
            theDelivery = this.getDelivery();
            if (this.delivery!= null) {
                currentHashCode += theDelivery.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            Duration theExpires;
            theExpires = this.getExpires();
            if (this.expires!= null) {
                currentHashCode += theExpires.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            FilterType theFilter;
            theFilter = this.getFilter();
            if (this.filter!= null) {
                currentHashCode += theFilter.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            EndpointReferenceType theEndTo;
            theEndTo = this.getEndTo();
            strategy.appendField(locator, this, "endTo", buffer, theEndTo, (this.endTo!= null));
        }
        {
            DeliveryType theDelivery;
            theDelivery = this.getDelivery();
            strategy.appendField(locator, this, "delivery", buffer, theDelivery, (this.delivery!= null));
        }
        {
            Duration theExpires;
            theExpires = this.getExpires();
            strategy.appendField(locator, this, "expires", buffer, theExpires, (this.expires!= null));
        }
        {
            FilterType theFilter;
            theFilter = this.getFilter();
            strategy.appendField(locator, this, "filter", buffer, theFilter, (this.filter!= null));
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/soap/wseventing/model/Subscribe.java <==

package org.somda.sdc.dpws.soap.wseventing.model;

import java.time.Duration;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.common.util.DurationAdapter;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="EndTo" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType" minOccurs="0"/&gt;
 *         &lt;element name="Delivery" type="{http://schemas.xmlsoap.org/ws/2004/08/eventing}DeliveryType"/&gt;
 *         &lt;element name="Expires" type="{http://www.w3.org/2001/XMLSchema}duration" minOccurs="0"/&gt;
 *         &lt;element name="Filter" type="{http://schemas.xmlsoap.org/ws/2004/08/eventing}FilterType" minOccurs="0"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "endTo",
    "delivery",
    "expires",
    "filter",
    "any"
})
@XmlRootElement(name = "Subscribe", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
public class Subscribe implements ToString2
{

    @XmlElement(name = "EndTo", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
    protected EndpointReferenceType endTo;
    @XmlElement(name = "Delivery", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing", required = true)
    protected DeliveryType delivery;
    @XmlElement(name = "Expires", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing", type = String.class)
    @XmlJavaTypeAdapter(DurationAdapter.class)
    @XmlSchemaType(name = "duration")
    protected Duration expires;
    @XmlElement(name = "Filter", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
    protected FilterType filter;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the endTo property.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getEndTo() {
        return endTo;
    }

    /**
     * Sets the value of the endTo property.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setEndTo(EndpointReferenceType value) {
        this.endTo = value;
    }

    /**
     * Gets the value of the delivery property.
     * 
     * @return
     *     possible object is
     *     {@link DeliveryType }
     *     
     */
    public DeliveryType getDelivery() {
        return delivery;
    }

    /**
     * Sets the value of the delivery property.
     * 
     * @param value
     *     allowed object is
     *     {@link DeliveryType }
     *     
     */
    public void setDelivery(DeliveryType value) {
        this.delivery = value;
    }

    /**
     * Gets the value of the expires property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Duration getExpires() {
        return expires;
    }

    /**
     * Sets the value of the expires property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setExpires(Duration value) {
        this.expires = value;
    }

    /**
     * Gets the value of the filter property.
     * 
     * @return
     *     possible object is
     *     {@link FilterType }
     *     
     */
    public FilterType getFilter() {
        return filter;
    }

    /**
     * Sets the value of the filter property.
     * 
     * @param value
     *     allowed object is
     *     {@link FilterType }
     *     
     */
    public void setFilter(FilterType value) {
        this.filter = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final Subscribe that = ((Subscribe) object);
        {
            EndpointReferenceType leftEndTo;
            leftEndTo = this.getEndTo();
            EndpointReferenceType rightEndTo;
            rightEndTo = that.getEndTo();
            if (this.endTo!= null) {
                if (that.endTo!= null) {
                    if (!leftEndTo.equals(rightEndTo)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.endTo!= null) {
                    return false;
                }
            }
        }
        {
            DeliveryType leftDelivery;
            leftDelivery = this.getDelivery();
            DeliveryType rightDelivery;
            rightDelivery = that.getDelivery();
            if (this.delivery!= null) {
                if (that.delivery!= null) {
                    if (!leftDelivery.equals(rightDelivery)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.delivery!= null) {
                    return false;
                }
            }
        }
        {
            Duration leftExpires;
            leftExpires = this.getExpires();
            Duration rightExpires;
            rightExpires = that.getExpires();
            if (this.expires!= null) {
                if (that.expires!= null) {
                    if (!leftExpires.equals(rightExpires)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.expires!= null) {
                    return false;
                }
            }
        }
        {
            FilterType leftFilter;
            leftFilter = this.getFilter();
            FilterType rightFilter;
            rightFilter = that.getFilter();
            if (this.filter!= null) {
                if (that.filter!= null) {
                    if (!leftFilter.equals(rightFilter)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.filter!= null) {
                    return false;
                }
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            EndpointReferenceType theEndTo;
            theEndTo = this.getEndTo();
            if (this.endTo!= null) {
                currentHashCode += theEndTo.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            DeliveryType theDelivery;
            theDelivery = this.getDelivery();
            if (this.delivery!= null) {
                currentHashCode += theDelivery.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            Duration theExpires;
            theExpires = this.getExpires();
            if (this.expires!= null) {
                currentHashCode += theExpires.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            FilterType theFilter;
            theFilter = this.getFilter();
            if (this.filter!= null) {
                currentHashCode += theFilter.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            EndpointReferenceType theEndTo;
            theEndTo = this.getEndTo();
            strategy.appendField(locator, this, "endTo", buffer, theEndTo, (this.endTo!= null));
        }
        {
            DeliveryType theDelivery;
            theDelivery = this.getDelivery();
            strategy.appendField(locator, this, "delivery", buffer, theDelivery, (this.delivery!= null));
        }
        {
            Duration theExpires;
            theExpires = this.getExpires();
            strategy.appendField(locator, this, "expires", buffer, theExpires, (this.expires!= null));
        }
        {
            FilterType theFilter;
            theFilter = this.getFilter();
            strategy.appendField(locator, this, "filter", buffer, theFilter, (this.filter!= null));
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}
